==> DateTime-Locale-1.43.tar.gz: DateTime-Locale-1.43/share/st.pl <==
{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm\N{U+202f}a",
    Ehms => "E h:mm:ss\N{U+202f}a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    GyMd => "GGGGG y-MM-dd",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "MM-dd, E",
    MMM => "LLL",
    MMMEd => "MMM d, E",
    "MMMMW-count-one" => "'week' W 'of' MMM",
    "MMMMW-count-other" => "'week' W 'of' MMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "MM-dd",
    d => "d",
    h => "h\N{U+202f}a",
    hm => "h:mm\N{U+202f}a",
    hms => "h:mm:ss\N{U+202f}a",
    hmsv => "h:mm:ss\N{U+202f}a v",
    hmv => "h:mm\N{U+202f}a v",
    ms => "mm:ss",
    y => "y",
    yM => "y-MM",
    yMEd => "y-MM-dd, E",
    yMMM => "y MMM",
    yMMMEd => "y MMM d, E",
    yMMMM => "y MMMM",
    yMMMd => "y MMM d",
    yMd => "y-MM-dd",
    yQQQ => "y QQQ",
    yQQQQ => "y QQQQ",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "st",
  date_format_full => "y MMMM d, EEEE",
  date_format_long => "y MMMM d",
  date_format_medium => "y MMM d",
  date_format_short => "y-MM-dd",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "Mma",
    "Bed",
    "Rar",
    "Ne",
    "Hla",
    "Moq",
    "Son",
  ],
  day_format_narrow => [
    "M",
    "T",
    "W",
    "T",
    "F",
    "S",
    "S",
  ],
  day_format_wide => [
    "Mmantaha",
    "Labobedi",
    "Laboraru",
    "Labone",
    "Labohlane",
    "Moqebelo",
    "Sontaha",
  ],
  day_stand_alone_abbreviated => [
    "Mma",
    "Bed",
    "Rar",
    "Ne",
    "Hla",
    "Moq",
    "Son",
  ],
  day_stand_alone_narrow => [
    "M",
    "T",
    "W",
    "T",
    "F",
    "S",
    "S",
  ],
  day_stand_alone_wide => [
    "Mmantaha",
    "Labobedi",
    "Laboraru",
    "Labone",
    "Labohlane",
    "Moqebelo",
    "Sontaha",
  ],
  era_abbreviated => [
    "BCE",
    "CE",
  ],
  era_narrow => [
    "BCE",
    "CE",
  ],
  era_wide => [
    "BCE",
    "CE",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Southern Sotho",
  month_format_abbreviated => [
    "Phe",
    "Kol",
    "Ube",
    "Mme",
    "Mot",
    "Jan",
    "Upu",
    "Pha",
    "Leo",
    "Mph",
    "Pun",
    "Tsh",
  ],
  month_format_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_format_wide => [
    "Phesekgong",
    "Hlakola",
    "Hlakubele",
    "Mmese",
    "Motsheanong",
    "Phupjane",
    "Phupu",
    "Phata",
    "Leotshe",
    "Mphalane",
    "Pundungwane",
    "Tshitwe",
  ],
  month_stand_alone_abbreviated => [
    "Phe",
    "Kol",
    "Ube",
    "Mme",
    "Mot",
    "Jan",
    "Upu",
    "Pha",
    "Leo",
    "Mph",
    "Pun",
    "Tsh",
  ],
  month_stand_alone_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_stand_alone_wide => [
    "Phesekgong",
    "Hlakola",
    "Hlakubele",
    "Mmese",
    "Motsheanong",
    "Phupjane",
    "Phupu",
    "Phata",
    "Leotshe",
    "Mphalane",
    "Pundungwane",
    "Tshitwe",
  ],
  name => "Southern Sotho",
  native_language => "Sesotho",
  native_name => "Sesotho",
  native_script => undef,
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  script => undef,
  territory => undef,
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 45,
}

==> DateTime-Locale-1.44.tar.gz: DateTime-Locale-1.44/share/st.pl <==
{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Ehm => "E h:mm\N{U+202f}a",
    Ehms => "E h:mm:ss\N{U+202f}a",
    Gy => "G y",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    GyMd => "GGGGG y-MM-dd",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "MM-dd, E",
    MMM => "LLL",
    MMMEd => "MMM d, E",
    "MMMMW-count-one" => "'week' W 'of' MMM",
    "MMMMW-count-other" => "'week' W 'of' MMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "MM-dd",
    d => "d",
    h => "h\N{U+202f}a",
    hm => "h:mm\N{U+202f}a",
    hms => "h:mm:ss\N{U+202f}a",
    hmsv => "h:mm:ss\N{U+202f}a v",
    hmv => "h:mm\N{U+202f}a v",
    ms => "mm:ss",
    y => "y",
    yM => "y-MM",
    yMEd => "y-MM-dd, E",
    yMMM => "y MMM",
    yMMMEd => "y MMM d, E",
    yMMMM => "y MMMM",
    yMMMd => "y MMM d",
    yMd => "y-MM-dd",
    yQQQ => "y QQQ",
    yQQQQ => "y QQQQ",
    "yw-count-other" => "'week' w 'of' Y",
  },
  code => "st",
  date_format_full => "y MMMM d, EEEE",
  date_format_long => "y MMMM d",
  date_format_medium => "y MMM d",
  date_format_short => "y-MM-dd",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "Mma",
    "Bed",
    "Rar",
    "Ne",
    "Hla",
    "Moq",
    "Son",
  ],
  day_format_narrow => [
    "M",
    "T",
    "W",
    "T",
    "F",
    "S",
    "S",
  ],
  day_format_wide => [
    "Mantaha",
    "Labobedi",
    "Laboraro",
    "Labone",
    "Labohlano",
    "Moqebelo",
    "Sontaha",
  ],
  day_stand_alone_abbreviated => [
    "Mma",
    "Bed",
    "Rar",
    "Ne",
    "Hla",
    "Moq",
    "Son",
  ],
  day_stand_alone_narrow => [
    "M",
    "T",
    "W",
    "T",
    "F",
    "S",
    "S",
  ],
  day_stand_alone_wide => [
    "Mantaha",
    "Labobedi",
    "Laboraro",
    "Labone",
    "Labohlano",
    "Moqebelo",
    "Sontaha",
  ],
  era_abbreviated => [
    "BCE",
    "CE",
  ],
  era_narrow => [
    "BCE",
    "CE",
  ],
  era_wide => [
    "BCE",
    "CE",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Southern Sotho",
  month_format_abbreviated => [
    "Phe",
    "Kol",
    "Ube",
    "Mme",
    "Mot",
    "Jan",
    "Upu",
    "Pha",
    "Leo",
    "Mph",
    "Pun",
    "Tsh",
  ],
  month_format_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_format_wide => [
    "Pherekgong",
    "Hlakola",
    "Hlakubele",
    "Mmesa",
    "Motsheanong",
    "Phupjane",
    "Phupu",
    "Phato",
    "Lwetse",
    "Mphalane",
    "Pudungwana",
    "Tshitwe",
  ],
  month_stand_alone_abbreviated => [
    "Phe",
    "Kol",
    "Ube",
    "Mme",
    "Mot",
    "Jan",
    "Upu",
    "Pha",
    "Leo",
    "Mph",
    "Pun",
    "Tsh",
  ],
  month_stand_alone_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_stand_alone_wide => [
    "Pherekgong",
    "Hlakola",
    "Hlakubele",
    "Mmesa",
    "Motsheanong",
    "Phupjane",
    "Phupu",
    "Phato",
    "Lwetse",
    "Mphalane",
    "Pudungwana",
    "Tshitwe",
  ],
  name => "Southern Sotho",
  native_language => "Sesotho",
  native_name => "Sesotho",
  native_script => undef,
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_abbreviated => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "Q1",
    "Q2",
    "Q3",
    "Q4",
  ],
  script => undef,
  territory => undef,
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 46,
}
